Kontrollvirksomhet signal | Bane NOR Oppslagsverk
Description: Viktig og nyttig informasjon for alle som har kontrollfunksjoner signal og jobber i signalanleggene til Bane NOR i Norge.

#
Kontrollvirksomhet signal

Viktig og nyttig informasjon for alle som har kontrollfunksjoner signal og jobber i signalanleggene til Bane NOR i Norge.

## Innhold

- Nyttige lenker
- Tidligere kunngjøringer

## Viktig informasjon

23. mars 2025 23. mar. 2025

### 23. mars 2025 23. mar. 2025 : Kurs i regler for kontroll signal

Obligatorisk RFK-kurs (Regler for kontroll signal) for alle sporveksel, kontrollør og sikkerhetskontrollører signal for høsten 2025 ligger nå klar for påmelding i Driv.
Kurset varer 1 dag og foregår lokalt rund i Norge på følgende steder:
Fredrikstad-Ski-Lillestrøm-Trondheim-Grong-Drammen-Oslo-Hamar-Gol-Voss-Bergen-Skien-Mo i Rana- Narvik-Kristiansand-Bryne-Otta
For funksjons- og sluttkontrollører signal vil de to tilgjengelige datoene for oppdateringskurset i RFK være 3. eller 13. juni 2025 på Thon hotel Opera i Oslo. Dette kurset varer 1 dag.

Påmelding skjer via Driv.

24. januar 2025 24. jan. 2025

### 24. januar 2025 24. jan. 2025 : PCB på Relerommene

Bare til informasjon!

PCB inneholder farlige stoffer. Disse kondensatorene finnes i forbindelse med sporfelt og avsporingsindikatorer, og også på reservelagrene. Dersom du er på et relerom, ikke kom borti disse uten å bruke hansker!

De bør skiftes ut med ny type (se eksempel helt til høyre under) og behandles som farlig avfall(åpnes i ny fane)
når de skal leveres til lokal søppelhåndtering.

SJA Driftsingeniørene jobber med å få fjernet dem fra Anlegget. Har du sett dem, send gjerne en e-post med hvilken Stasjon dette gjelder til: Lars.Hansen.Lier@banenor.no

Bane NOR

Ny type kondensator (se bilde helt til høyre over)

- Kondensator er på 0,68 mikrofarad og har artikkelnummer: 116013
- Brakett har artikkelnummer: 116834
- Plasthette/isolerende deksel har artikkelnummer: 116039

Flere detaljer kan finnes i Maximo -> Artikler (BN).

Finn mer informasjon i akseptnotat i Saksrom(åpnes i ny fane)
.